@@ -4,7 +4,7 @@
 from jsonpath_expression.jsonpath_expression import JsonpathExpression
 
 if  __name__ == "__main__" :
-    js = JsonpathExpression()
+    je= JsonpathExpression()
     str1='{}'
-    dic = js.jsonpath_expression(str1,1)
-    js.test_jsonpath_expression(str1,dic)
+    exp_list = je.jsonpath_expression(str1,1)
+    je.test_jsonpath_expression(str1,exp_list)
